ColumnMaker class

ColumnMaker With this class you can build a column with some text and alignment This is a good approach if you want to do a receipt like With text , width and align you can build a row as you like with any combination of alignment and size

Constructors

ColumnMaker({String text = '', int width = 2, SunmiPrintAlign align = SunmiPrintAlign.LEFT})

Properties

align ↔ SunmiPrintAlign
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited