SunmiStyle class

SunmiStyle

With this class you can build your own layout to print some text. The text can come already with align, fontSize and bold, and then you don't need to type 3 commands to do the same THING!

Constructors

SunmiStyle({SunmiFontSize? fontSize, SunmiPrintAlign? align, bool? bold})

Properties

align ↔ SunmiPrintAlign?
getter/setter pair
bold ↔ bool?
getter/setter pair
fontSize ↔ SunmiFontSize?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited